"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bullmq_1 = require("bullmq");
const utils_1 = require("./utils");
const ioredis_1 = __importDefault(require("ioredis"));
const fs_1 = __importDefault(require("fs"));
let queue;
async function getQueue() {
    if (!queue) {
        return utils_1.throwYellow("Need connect before");
    }
    await queue.waitUntilReady();
    return queue;
}
exports.getQueue = getQueue;
async function setQueue(name, prefix, options) {
    queue && (await queue.close());
    const client = new ioredis_1.default(options);
    queue = new bullmq_1.Queue(name, { connection: client, ...{ prefix } });
    await queue.waitUntilReady();
    return queue;
}
exports.setQueue = setQueue;
async function connectToQueue({ queue: name, options }, vorpal) {
    var _a;
    const prefix = options.prefix || "bull";
    const host = options.host || "localhost";
    const port = options.port || 6379;
    const db = (_a = options.db) !== null && _a !== void 0 ? _a : 0;
    const password = options.password || void 0;
    const tls = options.cert
        ? {
            ca: fs_1.default.readFileSync(options.cert),
            rejectUnauthorized: false
        }
        : void 0;
    await setQueue(name, prefix, {
        host,
        port,
        db,
        password,
        tls
    });
    vorpal.localStorage.setItem(utils_1.LAST_SAVED_CONNECTION_NAME, JSON.stringify({
        queue: name,
        options
    }));
    utils_1.logGreen(`Connected to ${host}:${port}, prefix: ${prefix}, queue: ${name}`);
    vorpal.delimiter(`BULL-REPL | ${prefix}.${name}> `).show();
}
exports.connectToQueue = connectToQueue;
